@@ -1259,7 +1259,7 @@ class ConfigHandler:
 
 
 class PipelineEndpointLauncher:
-    def start(self, ws, svc_pr, endpoint_pipeline, experiment_name, json_data):
+    def start(self, ws, svc_pr, endpoint_pipeline, json_data):
         """The PIPELINE_ENDPOINT pipeline is launched through its published REST address.
         """
         #workspaceProvider = WorkspaceProvider(self.config)
